lavalink_rs.model.track API documentation

# lavalink_rs.model.track

class TrackLoadType:

The type of data returned when loading a track.

Track = TrackLoadType.Track
Playlist = TrackLoadType.Playlist
Search = TrackLoadType.Search
Empty = TrackLoadType.Empty
Error = TrackLoadType.Error
class Track:
data
load_type
class TrackData:

Information about a track.

plugin_info
encoded
info
user_data
class TrackInfo:

Information and metadata about the track.

uri

The track uri.

is_stream

Whether the track is a stream.

isrc

The track "International Standard Recording Code".

identifier

The track identifier.

length

The track length in milliseconds.

author

The track author.

source_name

The track source name.

title

The track title,

artwork_url

The track artwork url.

is_seekable

Whether the track is seekable.

position

The track starting position in milliseconds.

class PlaylistData:
info
plugin_info
tracks
class PlaylistInfo:
name

The name of the playlist.

selected_track

The selected track of the playlist.

None if no track is selected.

class TrackError:
cause

The cause of the exception.

message

The message of the exception.

severity

The severity of the exception.